@@ -91,7 +91,7 @@ protected:
 		symbol_entry const & symbol;
 		sample_entry const & sample;
 		size_t pclass;
-		mutable counts_t & counts;
+		counts_t & counts;
 		extra_images const & extra;
 		double diff;
 	};
@@ -119,7 +119,8 @@ protected:
  
 	/// decribe one field of the colummned output.
 	struct field_description {
-		field_description() {}
+		field_description()
+			: width(0), header_name(""), formatter(NULL) {}
 		field_description(std::size_t w, std::string h,
 				  fct_format f)
 			: width(w), header_name(h), formatter(f) {}
